@@ -131,6 +131,23 @@ impl Grid {
         self.cells[row][column].as_str()
     }
 
+    /// get_cell_settings returns a settings of a cell
+    pub fn get_cell_settings(&mut self, row: usize, column: usize) -> Settings {
+        let style = self.style(row, column);
+        let content = &self.cells[row][column];
+        Settings::default()
+            .text(content)
+            .alignment(style.alignment_h)
+            .vertical_alignment(style.alignment_v)
+            .set_span(style.span)
+            .indent(
+                style.indent.left,
+                style.indent.right,
+                style.indent.top,
+                style.indent.bottom,
+            )
+    }
+
     /// Count_rows returns an amount of rows on the grid
     pub fn count_rows(&self) -> usize {
         self.size.0
@@ -181,7 +198,7 @@ impl Grid {
         self.size.0 += 1;
     }
 
-    /// Remove_row removes a `row` from a grid.
+    /// Removes a `row` from a grid.
     ///
     /// The row index must be started from 0
     pub fn remove_row(&mut self, row: usize) {
@@ -190,7 +207,7 @@ impl Grid {
         self.size.0 -= 1;
     }
 
-    /// Remove_row removes a `column` from a grid.
+    /// Removes a `column` from a grid.
     ///
     /// The column index must be started from 0
     pub fn remove_column(&mut self, column: usize) {
